@@ -1235,7 +1235,37 @@ def test_compose(source: str, expected: str) -> None:
             IOError
                 If something else goes wrong.
             """,
-            9,
+            72,
+        ),
+        (
+                """
+                Parameters
+                ----------
+                a: int
+                    description
+                b: int
+                    description
+    
+                Returns
+                -------
+                int
+                    The return value
+    
+                Yields
+                ------
+                str
+                    The yielded value
+    
+                Raises
+                ------
+                ValueError
+                    If something goes wrong.
+                TypeError
+                    If something else goes wrong.
+                IOError
+                    If something else goes wrong.
+                """,
+                70,
         ),
         (
                 """
@@ -1260,6 +1290,25 @@ def test_compose(source: str, expected: str) -> None:
                 """,
                 2,  # because numpy style parser can't parse other styles
         ),
+        (
+                """
+                Args:
+                    a (int): description
+                    b (int): description
+
+                Returns:
+                    int: The return value
+
+                Yields:
+                    str: The yielded value
+
+                Raises:
+                    ValueError: If something goes wrong.
+                    TypeError: If something else goes wrong.
+                    IOError: If something else goes wrong.
+                """,
+                2,  # because the Arg section are parsed into long/short descriptions
+        ),
         (
                 """
                 Short description.
@@ -1280,6 +1329,22 @@ def test_compose(source: str, expected: str) -> None:
                 """,
                 2,  # because numpy style parser can't parse other styles
         ),
+        (
+                """
+                :param a: description
+                :type a: int
+                :param b: description
+                :type b: int
+                :returns: The return value
+                :rtype: int
+                :yield: The yielded value
+                :rtype: str
+                :raises ValueError: If something goes wrong.
+                :raises TypeError: If something else goes wrong.
+                :raises IOError: If something else goes wrong.
+                """,
+                2,  # because the beginning is parsed into long/short descriptions
+        ),
     ],
 )
 def test_docstring_size(src: str, expected_size: int) -> None:
